@@ -1,4 +1,4 @@
-#' Plot quality-control metrics and thresholds of a `"nacho"` object
+#' Plot quality-control metrics and thresholds of a "nacho" object
 #'
 #' This function allows to plot any qualit-control figures available
 #' within the shiny app using [`visualise()`] or in the HTML report from [`render()`].
@@ -578,8 +578,8 @@ plot_pca12 <- function(
       colour = .data[[colour]]
     )
   ) +
+    ggforce::geom_mark_ellipse(na.rm = TRUE, alpha = 0.1) +
     ggplot2::geom_point(size = size, na.rm = TRUE) +
-    ggforce::geom_mark_ellipse(na.rm = TRUE) +
     ggplot2::scale_colour_viridis_d(option = "plasma", direction = 1, end = 0.85) +
     ggplot2::scale_fill_viridis_d(option = "plasma", direction = 1, end = 0.85) +
     ggplot2::scale_x_continuous(expand = ggplot2::expand_scale(0.25)) +
@@ -635,8 +635,8 @@ plot_pca <- function(
       fill = .data[[colour]]
     )
   ) +
+    ggforce::geom_mark_ellipse(na.rm = TRUE, alpha = 0.1) +
     ggplot2::geom_point(size = size, na.rm = TRUE) +
-    ggforce::geom_mark_ellipse(na.rm = TRUE) +
     ggplot2::scale_colour_viridis_d(option = "plasma", direction = 1, end = 0.85) +
     ggplot2::scale_fill_viridis_d(option = "plasma", direction = 1, end = 0.85) +
     ggplot2::scale_x_continuous(expand = ggplot2::expand_scale(0.25)) +
